@@ -6,18 +6,21 @@ from collections_extended import setlist
 from fastapi import Query
 from lxml import etree
 from progress.bar import Bar
-from pydantic import BaseModel, Field
+from pydantic import BaseModel
 from pydantic.dataclasses import dataclass
 from pyimporters_plugins.base import KnowledgeParserBase, KnowledgeParserOptions, Term, maybe_archive
 
 
-# from xml import etree
 @dataclass
 class MeSHOptions(KnowledgeParserOptions):
     """
     Options for the MeSH knowledge import
     """
-    branches : str = Query(None, description="Comma-separated list of branches to import, for example 'B,C' to import only descriptors belonging to the Organisms & Diseases categories")
+    branches: str = Query(None,
+                          description="""Comma-separated list of branches to import,
+                                         for example 'B,C' to import only descriptors
+                                         belonging to the Organisms & Diseases categories""")
+
 
 MeSHOptionsModel = MeSHOptions.__pydantic_model__
 
@@ -43,15 +46,17 @@ MESH_CATEGORIES = {
 
 
 class MeSHKnowledgeParser(KnowledgeParserBase):
-    def parse(self, source: Path, options: Union[KnowledgeParserOptions, Dict[str, Any]], bar: Bar) -> Generator[Term, None, None]:
+    def parse(self, source: Path, options: Union[KnowledgeParserOptions, Dict[str, Any]], bar: Bar) \
+            -> Generator[Term, None, None]:
         options = MeSHOptions(**options) if isinstance(options, dict) else options
-        allowed_branches = [b.strip() for b in options.branches.split(",") if b.strip() in MESH_CATEGORIES] if options.branches else list(MESH_CATEGORIES.keys())
+        allowed_branches = [b.strip() for b in options.branches.split(",") if
+                            b.strip() in MESH_CATEGORIES] if options.branches else list(MESH_CATEGORIES.keys())
         with maybe_archive(source) as file:
             mesh = etree.parse(file)
             bar.max = int(mesh.xpath("count(//DescriptorRecord)"))
         bar.start()
         try:
-            with maybe_archive(source) as file:
+            with maybe_archive(source, mode='rb') as file:
                 mesh = etree.iterparse(file, events=("end",), tag=['DescriptorRecord'])
                 for event, record in mesh:
                     bar.next()
@@ -78,10 +83,6 @@ class MeSHKnowledgeParser(KnowledgeParserBase):
 
                     record.clear()
                     if intersection(allowed_branches, props['Branch']):
-
-                        # for qualifier in record.iterfind("./AllowableQualifiersList/AllowableQualifier/QualifierReferredTo"):
-                        #     qid = qualifier.findtext("QualifierUI")
-                        #     props['AllowableQualifier'].append(qid)
                         term: Term = Term(identifier=dui, preferredForm=norm, properties=props)
                         yield term
         finally:
@@ -95,7 +96,8 @@ class MeSHKnowledgeParser(KnowledgeParserBase):
     def get_model(cls) -> Type[BaseModel]:
         return MeSHOptionsModel
 
+
 # Python program to illustrate the intersection
 # of two lists using set() method
 def intersection(lst1, lst2):
-    return list(set(lst1) & set(lst2))
\ No newline at end of file
+    return list(set(lst1) & set(lst2))
